@@ -35,6 +35,7 @@ module Control.Retry
       RetryPolicyM (..)
     , RetryPolicy
     , retryPolicy
+    , natTransformRetryPolicy
     , RetryStatus (..)
     , defaultRetryStatus
     , applyPolicy
@@ -176,6 +177,21 @@ instance Monad m => Monoid (RetryPolicyM m) where
 #endif
 
 
+-------------------------------------------------------------------------------
+-- | Applies a natural transformation to a policy to run a RetryPolicy
+-- meant for the monad @m@ in the monad @n@ provided a transformation
+-- from @m@ to @n@ is available. A common case is if you have a pure
+-- policy, @RetryPolicyM Identity@ and want to use it to govern an
+-- @IO@ computation you could write:
+--
+-- @
+--   purePolicyInIO :: RetryPolicyM Identity -> RetryPolicyM IO
+--   purePolicyInIO = natTransformRetryPolicy (pure . runIdentity)
+-- @
+natTransformRetryPolicy :: (forall a. m a -> n a) -> RetryPolicyM m -> RetryPolicyM n
+natTransformRetryPolicy f (RetryPolicyM p) = RetryPolicyM $ \stat -> f (p stat)
+
+
 -------------------------------------------------------------------------------
 -- | Datatype with stats about retries made thus far. The constructor
 -- is deliberately not exported to make additional fields easier to
@@ -428,7 +444,7 @@ retrying policy chk f = go defaultRetryStatus
 -- good idea to catch async exceptions as it can result in hanging
 -- threads and programs. Note that if you just throw an exception to
 -- this thread that does not descend from SomeException, recoverAll
--- will catch it.
+-- will not catch it.
 --
 -- See how the action below is run once and retried 5 more times
 -- before finally failing for good:
